# Generated by roxygen2: do not edit by hand

S3method(px_add_totals,px)
S3method(px_aggregallowed,px)
S3method(px_autopen,px)
S3method(px_axis_version,px)
S3method(px_baseperiod,px)
S3method(px_cellnote,px)
S3method(px_cellnotex,px)
S3method(px_cfprices,px)
S3method(px_charset,px)
S3method(px_codepage,px)
S3method(px_confidential,px)
S3method(px_contact,px)
S3method(px_contents,px)
S3method(px_contvariable,px)
S3method(px_copyright,px)
S3method(px_creation_date,px)
S3method(px_data,px)
S3method(px_database,px)
S3method(px_datasymbol1,px)
S3method(px_datasymbol2,px)
S3method(px_datasymbol3,px)
S3method(px_datasymbol4,px)
S3method(px_datasymbol5,px)
S3method(px_datasymbol6,px)
S3method(px_datasymbolnil,px)
S3method(px_decimals,px)
S3method(px_description,px)
S3method(px_descriptiondefault,px)
S3method(px_domain,px)
S3method(px_elimination,px)
S3method(px_figures,px)
S3method(px_heading,px)
S3method(px_infofile,px)
S3method(px_language,px)
S3method(px_languages,px)
S3method(px_last_updated,px)
S3method(px_link,px)
S3method(px_map,px)
S3method(px_matrix,px)
S3method(px_next_update,px)
S3method(px_note,px)
S3method(px_notex,px)
S3method(px_official_statistics,px)
S3method(px_order,px)
S3method(px_precision,px)
S3method(px_refperiod,px)
S3method(px_showdecimals,px)
S3method(px_source,px)
S3method(px_stockfa,px)
S3method(px_stub,px)
S3method(px_subject_area,px)
S3method(px_subject_code,px)
S3method(px_tableid,px)
S3method(px_timeval,px)
S3method(px_title,px)
S3method(px_units,px)
S3method(px_update_frequency,px)
S3method(px_valuenote,px)
S3method(px_valuenotex,px)
S3method(px_values,px)
S3method(px_variable_label,px)
S3method(px_variable_type,px)
export(px)
export(px_add_totals)
export(px_aggregallowed)
export(px_autopen)
export(px_axis_version)
export(px_baseperiod)
export(px_cellnote)
export(px_cellnotex)
export(px_cfprices)
export(px_charset)
export(px_classification)
export(px_codepage)
export(px_confidential)
export(px_contact)
export(px_contents)
export(px_contvariable)
export(px_copyright)
export(px_creation_date)
export(px_data)
export(px_database)
export(px_datasymbol1)
export(px_datasymbol2)
export(px_datasymbol3)
export(px_datasymbol4)
export(px_datasymbol5)
export(px_datasymbol6)
export(px_datasymbolnil)
export(px_decimals)
export(px_description)
export(px_descriptiondefault)
export(px_domain)
export(px_elimination)
export(px_figures)
export(px_heading)
export(px_infofile)
export(px_language)
export(px_languages)
export(px_last_updated)
export(px_link)
export(px_map)
export(px_matrix)
export(px_micro)
export(px_next_update)
export(px_note)
export(px_notex)
export(px_official_statistics)
export(px_order)
export(px_precision)
export(px_refperiod)
export(px_save)
export(px_save_classification)
export(px_showdecimals)
export(px_source)
export(px_stockfa)
export(px_stub)
export(px_subject_area)
export(px_subject_code)
export(px_tableid)
export(px_timeval)
export(px_title)
export(px_units)
export(px_update_frequency)
export(px_validate)
export(px_valuenote)
export(px_valuenotex)
export(px_values)
export(px_variable_label)
export(px_variable_type)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,any_of)
importFrom(dplyr,desc)
importFrom(dplyr,ends_with)
importFrom(dplyr,everything)
importFrom(dplyr,if_any)
importFrom(dplyr,last_col)
importFrom(dplyr,one_of)
importFrom(dplyr,starts_with)
importFrom(dplyr,where)
importFrom(magrittr,"%>%")
importFrom(methods,as)
importFrom(rlang,":=")
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(utils,head)
importFrom(utils,tail)
