#' @keywords internal
#' @aliases pxmake-package.R
"_PACKAGE"

## usethis namespace: start
#' @importFrom dplyr across
#' @importFrom dplyr all_of
#' @importFrom dplyr any_of
#' @importFrom dplyr desc
#' @importFrom dplyr ends_with
#' @importFrom dplyr everything
#' @importFrom dplyr if_any
#' @importFrom dplyr last_col
#' @importFrom dplyr one_of
#' @importFrom dplyr starts_with
#' @importFrom dplyr where
#' @importFrom magrittr %>%
#' @importFrom methods as
#' @importFrom rlang :=
#' @importFrom stats na.omit
#' @importFrom stats setNames
#' @importFrom utils head
#' @importFrom utils tail
## usethis namespace: end
NULL
