% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/px_file.R
\name{get_data_cube}
\alias{get_data_cube}
\title{Get data cube used in PX-file format}
\usage{
get_data_cube(metadata_df, data_df)
}
\arguments{
\item{metadata_df}{Data frame with metadata.}

\item{data_df}{A data frame with data.}
}
\value{
A data frame
}
\description{
Get data cube used in PX-file format
}
\keyword{internal}
