% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/note_warning_error.R
\name{error}
\alias{error}
\title{Throw error}
\usage{
error(msg)
}
\arguments{
\item{msg}{String, error message}
}
\value{
Nothing
}
\description{
Throw error
}
\keyword{internal}
