% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/px.R
\name{fix_px}
\alias{fix_px}
\title{Fix some common issues in px objects}
\usage{
fix_px(x)
}
\arguments{
\item{x}{A px object.}
}
\value{
A px object
}
\description{
Fix some common issues in px objects
}
\keyword{internal}
