% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/helper_functions.R
\name{str_quote}
\alias{str_quote}
\title{Add quotes around string}
\usage{
str_quote(str)
}
\arguments{
\item{str}{String to quote}
}
\value{
String
}
\description{
Add quotes around string
}
\keyword{internal}
