% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/modify_data.R
\name{sort_data_table_by_order}
\alias{sort_data_table_by_order}
\title{Sort data table by order}
\usage{
sort_data_table_by_order(x)
}
\description{
Sort data table by order
}
\keyword{internal}
